# OpenSSL

OpenSSL este o implementare open-source a protocoalelor SSL și TLS. Pe lângă
API-uri pentru diverse limbaje de programare, această oferă și un utiliatar CLI,
**openssl**. Sintaxa pentru utilizarea în linia de
comandă este următoarea:

```
openssl comandă [opțiuni] [argumente]
```

Printre comenzi se numără:

 * **ca** - utilizată pentru managementul unei autorități de certificare (se pot genera certificate, care sunt stocate apoi într-o baza de date)\
 * **dgst** - pentru calculul de rezumate de mesaje\
 * **genrsa** - pentru generarea de chei RSA\
 * **req** - pentru crearea și procesarea de cereri de certificate; se poate utiliza și pentru generarea de certificate auto-semnate\
 * **verify** - pentru verificarea de certificate X.509

Pentru început, emiteți următoarea comandă pentru a verifică versiunea
de OpenSSL pe care o folosiți:

openssl version

Generarea cererii de certificat se realizează astfel. Exemplul următor
produce un fișier **mycert.pem** ce conține atât cheia privată, cât
și cea publică. Certificatul va fi valid timp de 365 de zile iar cheia
este neencriptata (opțiunea --nodes).

openssl req \ -new -newkey rsa:1024 -nodes \ -keyout mykey.pem -out myreq.pem

După apelul comenzii veți fi puși să răspundeți unei serii de întrebări
legate de: Țară, Stat, Oraș, etc.

Rezultatul va constă în crearea a două fișiere: **mykey.pem** va
conține cheia privată, iar **myreq.pem** va conține o cerere de
certificat. Cererea de certificat este trimisă (pe canale sigure) unei
autorități de semnare (de exemplu VeriSign). Puteți verifică conținutul
informațiilor conținute în cererea de certificat folosind:

```
# verificarea semnăturii
openssl req -in myreq.pem -noout -verify -key mykey.pem

# verificarea informațiilor
openssl req -in myreq.pem -noout -text </code>{=html}
```

După cum ați putut observă anterior, metodă de generare a cheii private
folosită a fost RSA. Metodă folosită însă realizaza și o cerere de
certificat. Puteți obține dacă doriți generarea doar a cheii private RSA
emițând o comand a precum:

```
# o cheie implicită pe 512-biți, afișată la ieșirea stdout
openssl genrsa

# o cheie pe 1024-biți, salvată în fișierul mykey.pem
openssl genrsa -out mykey.pem 1024

# că în exemplul anterior, dar cheia este protejată de o parolă
openssl genrsa -des3 -out mykey.pem 1024 </code>{=html}
```

Pornind de la cheia privată puteți mai departe să generați și o cheie
publică corespunzătoare astfel:

```
openssl rsa -in mykey.pem -pubout
```

Generarea digest-urilor folosind opțiunea //dgst// reprezintă un exemplu
de capabilitate oferită de OpenSSL.

```
# MD5 digest
openssl dgst -md5 filename

# SHA1 digest

openssl dgst -sha1 filename </code>{=html}
```

Digesturile MD5 sunt similare celor create cu comandă //md5sum//, deși
formatele de ieșire diferă.

```
$ openssl dgst -md5 foo-2.23.tar.gz
MD5(foo-2.23.tar.gz)= 81eda7985e99d28acd6d286aa0e13e07

$ md5sum foo-2.23.tar.gz
81eda7985e99d28acd6d286aa0e13e07 foo-2.23.tar.gz
```

Digesturile pot fi chiar semnate pentru a va asigura că ele nu pot fi
modificate fără permisiunea explicită a proprietarului.

```
# digestul semnat va fi foo-1.23.tar.gz.sha1
openssl dgst -sha1 -sign mykey.pem -out foo-1.23.tar.gz.sha1 foo-1.23.tar.gz
```

Ulterior, digestul poate fi verificat. Pentru această aveți nevoie de
fișierul din care digestul a fost generat, de digest, și de cheia
publică a semnatarului.

```
# pentru verificarea arhivei foo-1.23.tar.gz folosind foo-1.23.tar.gz.sha1 și cheia publică
# pubkey.pem
openssl dgst -sha1 -verify pubkey.pem -signature foo-1.23.tar.gz.sha1 foo-1.23.tar.gz
```

Un alt exemplu de folosire a OpenSSL este și cel legat de
criptarea/decriptarea unor documente. Astfel, pentru criptare puteți
emite o comandă precum:

```
# cripteaza file.txt la file.enc folosind 256-bit AES în modul CBC
openssl enc -aes-256-cbc -salt -in file.txt -out file.enc

# același lucru, dar ieșirea este de dată această codată base64. de exemplu pentru email
openssl enc -aes-256-cbc -a -salt -in file.txt -out file.enc
```

În cadrul exemplului a fost folosit unul dintre algoritmii de
criptografie suportați de OpenSSL. În practică însă puteți alege oricare
dintre cei suportați. Pentru a vedea care sunt algoritmii incluși în
distribuția OpenSSL pe care o folosiți puteți emite:

```
openssl list-cipher-commands
```

Decriptarea fișierului rezultat anterior poate fi realizată astfel:

```
# decriptarea fișierului binar file.enc
openssl enc -d -aes-256-cbc -in file.enc

# decriptarea versiunii base64
openssl enc -d -aes-256-cbc -a -in file.enc
```
