# Mininet

Mininet folosește python pentru a specifica o topologie. În următorul exemplu prezentăm o topologie
formată din 3 dispozitive, dintre care unul acționează ca un router.

```python
from mininet.topo import Topo
from mininet.cli import CLI
from mininet.net import Mininet

class MyTopo(Topo):
    "O topologie este definită ca o clasa ce moștenește Topo"

    def build(self):
        # Adăugăm dispozitivele din topologie: hosts și un switch de L2
        leftHost = self.addHost('host2')
        rightHost = self.addHost('host1')
        # Pe acest dispozitiv, teoretic ar trebui pornit un program ce
        # implementează protocolul de rutare
        router = self.addHost('router')

        # Adăugăm link-urile
        self.addLink(leftHost, router)
        self.addLink(rightHost, router)

# Instantiem topologia
topo = MyTopo()
# Pornim simularea
net = Mininet(topo)
net.start()

# Pornim terminalul de control al topologiei
CLI(net)
net.stop()
```

Vom folosi python pentru a rula topologia, presupunem că topologia se află în fișierul topo.py.

```bash
❯ pkill ovs-test # Doar prima data
❯ sudo python3 topo.py
mininet>
```

Din terminalul principal vom putea deschide terminale pe oricare dintre dispozitive:
``` Bash
# pornește un terminal pe host1
mininet> host1 xterm&
```

> Puteti folosi orice terminal, nu doar xterm (E.g. gnome-terminal).

Comanda precedentă va deschide un terminal, din acel terminal vom putea executa orice
binar de linux care se află și pe mașină noastră, precum `Wireshark`.

```
sudo wireshark&
```

Sau pentru depanare `ping`:

```
❯ ping router_ip
PING router_ip (router_ip) 56(84) bytes of dată.
64 bytes from host_ip: icmp_seq=1 ttl=58 time=21.2 ms
64 bytes from host_ip: icmp_seq=2 ttl=58 time=21.5 ms
64 bytes from host_ip: icmp_seq=3 ttl=58 time=20.6 ms
```

> Din terminalul unui dispozitiv putem rula ip address show pentru a vedea toate
interfețele disponibile și adresele IP de pe acestea.


